@@ -29,7 +29,7 @@ stat_ihh_class <- R6Class("stat_ihh", inherit = sumstat_class,
       private$use_ihs <- calc_ihs
       super$initialize(name, transformation)
     },
-    calculate = function(seg_sites, trees, files, model) {
+    calculate = function(seg_sites, trees, files, model, sim_tasks = NULL) {
       assert_that(is.list(seg_sites))
       assert_that(is.model(model))
       ind <- get_population_individuals(model, private$population)
