@@ -13,7 +13,7 @@ test_that("it creates the abc parameter data.frame", {
 })
 
 
-test_that("it creates abc sumstat data.frame", {
+test_that("a data.frame for abc can be created", {
   model <- model_theta_tau()
   sim_results <- simulate(model, pars = c(1, 5), nsim = 2)
   expect_warning(abc_sumstat <- create_abc_sumstat(sim_results, model))
