@@ -80,19 +80,29 @@ test_that("calculation of ihh works", {
   stat_ihh <- sumstat_ihh()
   ihh <- stat_ihh$calculate(list(seg_sites), NULL, NULL, model)
   expect_that(ihh, is_a("data.frame"))
-  expect_equal(dim(ihh), c(5, 6))
-  expect_equal(ihh$CHR, rep(1, 5))
+  expect_equal(dim(ihh), c(5, 7))
+  expect_equal(ihh$CHR, rep("1", 5))
   expect_equal(ihh$POSITION, pos)
 
   ihh <- stat_ihh$calculate(list(seg_sites, seg_sites), NULL, NULL,
                             coal_model(4, 2, 337))
   expect_that(ihh, is_a("data.frame"))
-  expect_equal(dim(ihh), c(10, 6))
-  expect_equal(ihh$CHR, rep(1:2, each = 5))
+  expect_equal(dim(ihh), c(10, 7))
+  expect_equal(ihh$CHR, rep(c("1", "2"), each = 5))
   expect_equal(ihh$POSITION, c(pos, pos))
 })
 
 
+test_that("ihh can be calculated for all populations", {
+  skip_if_not_installed("rehh")
+  stat_ihh <- sumstat_ihh(population = "all")
+  expect_equal(stat_ihh$calculate(list(seg_sites), NULL, NULL,
+                                  coal_model(c(2, 2), 1, 337)),
+               stat_ihh$calculate(list(seg_sites), NULL, NULL,
+                                  coal_model(4, 1, 337)))
+})
+
+
 test_that("calculation of ihs works", {
   skip_if_not_installed("rehh")
 
@@ -101,7 +111,7 @@ test_that("calculation of ihs works", {
   expect_that(ihh, is_a("list"))
   expect_that(ihh[[1]], is_a("data.frame"))
   expect_that(ihh[[2]], is_a("data.frame"))
-  expect_equal(dim(ihh[[1]]), c(5, 6))
+  expect_equal(nrow(ihh[[1]]), 5)
   expect_equal(ncol(ihh[[2]]), 3)
 
   model2 <- coal_model(50, 2, 1000) + feat_mutation(10) + sumstat_seg_sites()
@@ -150,17 +160,17 @@ test_that("ihh works with empty segsites", {
 
   stat <- ihh$calculate(seg_sites, NULL, NULL, coal_model(4, 2, 337))
   expect_that(stat, is_a("data.frame"))
-  expect_equal(dim(stat), c(5, 6))
+  expect_equal(nrow(stat), 5)
 
   seg_sites <- list(create_segsites(matrix(0, 0, 0), numeric(0)))
   stat <- ihh$calculate(seg_sites, NULL, NULL, model)
   expect_that(stat, is_a("data.frame"))
-  expect_equal(dim(stat), c(0, 6))
+  expect_equal(nrow(stat), 0)
 
   seg_sites <- list(create_segsites(matrix(1, 5, 10), 1:10 / 11))
   stat <- ihh$calculate(seg_sites, NULL, NULL, model)
   expect_that(stat, is_a("data.frame"))
-  expect_equal(dim(stat), c(0, 6))
+  expect_equal(nrow(stat), 0)
 
   ihh <- sumstat_ihh(population = 1, calc_ihs = TRUE)
   stat <- ihh$calculate(seg_sites, NULL, NULL, model)
